@@ -163,6 +163,12 @@ bool wxStfApp::OnInit(void)
     //// Create a document manager
     wxDocManager* docManager = new wxDocManager;
     //// Create a template relating drawing documents to their views
+#if (defined(WITH_BIOSIG) || defined(WITH_BIOSIG2))
+    m_biosigTemplate=new wxDocTemplate( docManager,
+                                     wxT("All files"), wxT("*.*"), wxT(""), wxT(""),
+                                     wxT("Biosig Document"), wxT("Biosig View"), CLASSINFO(wxStfDoc),
+                                     CLASSINFO(wxStfView) );
+#endif
 #if (defined(WITH_BIOSIG) || defined(WITH_BIOSIG2))
     m_biosigTemplate=new wxDocTemplate( docManager,
                                      wxT("Biosig files"), wxT("*.dat;*.cfs;*.gdf;*.ibw"), wxT(""), wxT(""),
@@ -185,8 +191,10 @@ bool wxStfApp::OnInit(void)
                                      CLASSINFO(wxStfView) );
 #if defined(__WXGTK__) || defined(__WXMAC__)
 #if !defined(__MINGW32__)
+#if !defined(WITHOUT_ABF)
     ABF_Initialize();
 #endif
+#endif
 #endif
     m_atfTemplate=new wxDocTemplate( docManager,
                                      wxT("Axon text file"), wxT("*.atf"), wxT(""), wxT("atf"),
@@ -206,12 +214,6 @@ bool wxStfApp::OnInit(void)
                                      wxT("CED Spike 2 (SON) file"), wxT("*.smr"), wxT(""), wxT(""),
                                      wxT("SON Document"), wxT("SON View"), CLASSINFO(wxStfDoc),
                                      CLASSINFO(wxStfView) );
-#endif
-#if (defined(WITH_BIOSIG) || defined(WITH_BIOSIG2))
-    m_biosigTemplate=new wxDocTemplate( docManager,
-                                     wxT("Biosig files"), wxT("*.*"), wxT(""), wxT(""),
-                                     wxT("Biosig Document"), wxT("Biosig View"), CLASSINFO(wxStfDoc),
-                                     CLASSINFO(wxStfView) );
 #endif
     m_txtTemplate=new wxDocTemplate( docManager,
                                      wxT("General text file import"), wxT("*.*"), wxT(""), wxT(""),
@@ -423,6 +425,8 @@ void wxStfApp::OnPeakcalcexecMsg(wxStfDoc* actDoc) {
          case stf::measure_cursor: 
              actDoc->SetMeasCursor(CursorsDialog->GetCursorM());// * GetDocument()->GetSR()));
              wxWriteProfileInt(wxT("Settings"), wxT("MeasureCursor"), CursorsDialog->GetCursorM() );
+             actDoc->SetMeasRuler( CursorsDialog->GetRuler() );
+             wxWriteProfileInt(wxT("Settings"), wxT("ShowRuler"), CursorsDialog->GetRuler() );
              break;
          
              //Get limits for peak calculation from the dialog box:
@@ -433,8 +437,10 @@ void wxStfApp::OnPeakcalcexecMsg(wxStfDoc* actDoc) {
              break;
          
          case stf::base_cursor: 
+             wxWriteProfileInt(wxT("Settings"), wxT("BaselineMethod"), CursorsDialog->GetBaselineMethod());
              actDoc->SetBaseBeg(CursorsDialog->GetCursor1B());
              actDoc->SetBaseEnd(CursorsDialog->GetCursor2B());
+             actDoc->SetBaselineMethod(CursorsDialog->GetBaselineMethod());
              break;
          
          case stf::decay_cursor: 
@@ -495,6 +501,7 @@ void wxStfApp::OnPeakcalcexecMsg(wxStfDoc* actDoc) {
         }
 
 
+        wxWriteProfileInt(wxT("Settings"), wxT("PeakAtEnd"), CursorsDialog->GetPeakAtEnd() );
         //Update edit peak limits in the peak calculation dialog box
         if (CursorsDialog->GetPeakAtEnd())
         {	//If 'Upper limit at end of trace' is selected in the dialog box
@@ -509,6 +516,9 @@ void wxStfApp::OnPeakcalcexecMsg(wxStfDoc* actDoc) {
             }
             actDoc->SetPeakAtEnd(true);
         }
+        else {
+            actDoc->SetPeakAtEnd(false);
+        }
         // Get number of peak points from the dialog box...
         actDoc->SetPM(CursorsDialog->GetPeakPoints());
         wxWriteProfileInt(wxT("Settings"),wxT("PeakMean"),(int)actDoc->GetPM());
@@ -531,6 +541,22 @@ void wxStfApp::OnPeakcalcexecMsg(wxStfDoc* actDoc) {
         wxsSlope << CursorsDialog->GetSlope();
         wxWriteProfileString(wxT("Settings"), wxT("Slope"), wxsSlope);
 
+        wxWriteProfileInt(wxT("Settings"), wxT("StartFitAtPeak"), CursorsDialog->GetStartFitAtPeak() );
+        //Update start fit at peak
+        if ( CursorsDialog->GetStartFitAtPeak() ) {
+            actDoc->SetFitBeg( actDoc->GetMaxT() );
+            actDoc->SetStartFitAtPeak(true);
+            try {
+                CursorsDialog->UpdateCursors();
+            }
+            catch (const std::runtime_error& e) {
+                ExceptMsg(wxString( e.what(), wxConvLocal ));
+                return;
+            }
+        }
+        else {
+            actDoc->SetStartFitAtPeak(false);
+        }
 
     }
 
@@ -544,19 +570,27 @@ void wxStfApp::OnPeakcalcexecMsg(wxStfDoc* actDoc) {
     catch (const std::out_of_range& e) {
         ExceptMsg(wxString( e.what(), wxConvLocal ));
     }
-
+    /*
     // Set fit start cursor to new peak if necessary.
+        //std::cout << CursorsDialog->GetPeakAtEnd() << std::endl;
+    //wxWriteProfileInt(wxT("Settings"), wxT("StartFitAtPeak"), CursorsDialog->GetStartFitAtPeak() );
     if (actDoc != NULL && CursorsDialog != NULL && CursorsDialog->GetStartFitAtPeak())
+    //if ( CursorsDialog->GetStartFitAtPeak() )
     {
-        actDoc->SetFitBeg(actDoc->GetMaxT());
-        try {
-            CursorsDialog->UpdateCursors();
-        }
-        catch (const std::runtime_error& e) {
-            ExceptMsg(wxString( e.what(), wxConvLocal ));
-            return;
-        }
+        //actDoc->SetFitBeg(actDoc->GetMaxT());
+        actDoc->SetStartFitAtPeak( true );
+        //try {
+        //    CursorsDialog->UpdateCursors();
+        //}
+        //catch (const std::runtime_error& e) {
+        //    ExceptMsg(wxString( e.what(), wxConvLocal ));
+        //    return;
+        //}
     }
+    else {
+        actDoc->SetStartFitAtPeak( true );
+    }
+    */
 
     // Updates strings in the result box
     if (actView != NULL) {
