@@ -37,7 +37,7 @@ class StfDll wxStfDoc: public wxDocument, public Recording
     DECLARE_DYNAMIC_CLASS(wxStfDoc)
 #endif
 private:
-    bool peakAtEnd, initialized, progress;
+    bool peakAtEnd, startFitAtPeak, initialized, progress;
     Recording Average;
     int InitCursors();
     void PostInit();
@@ -82,12 +82,14 @@ private:
     stf::pslope_mode_end pslopeEndMode; // for right mode PSlope cursor
 #endif 
     std::size_t baseBeg, baseEnd, peakBeg, peakEnd, fitBeg, fitEnd; 
+    stf::baseline_method baselineMethod; // method for calculating baseline
 #ifdef WITH_PSLOPE
     std::size_t PSlopeBeg, PSlopeEnd;
     int DeltaT;  // distance (number of points) from the first cursor
     bool viewPSlope;
 #endif
     std::size_t measCursor;
+    bool ShowRuler; // show a ruler throught the measurement cursor?
     double latencyStartCursor,
         latencyEndCursor,
         latency,	 //time from latency cursor to beginning of event
@@ -177,6 +179,11 @@ public:
      */
     bool GetIsAverage() const { return !Average.get().empty(); }
 
+    //! Indicates whether the left decay cursor should always be at the peak of the trace.
+    /*! \return true if the left decay cursor should be at the end of the trace, false otherwise.
+     */
+    bool GetStartFitAtPeak() const { return startFitAtPeak; }
+
     //! Indicates whether the right peak cursor should always be at the end of a trace.
     /*! \return true if the right peak cursor should be at the end, false otherwise.
      */
@@ -195,6 +202,11 @@ public:
      */
     void SetPeakAtEnd(bool value) { peakAtEnd=value; }
 
+    //! Sets the left decay cursor to the peak of the trace.
+    /*! \param value determines whether the left decay cursor should be at the peak of the trace.
+     */
+    void SetStartFitAtPeak(bool value) { startFitAtPeak=value; }
+
     //! Retrieves the average trace(s).
     /*! \return The average trace as a Recording object.
      */
@@ -295,6 +307,11 @@ public:
      */
     std::size_t GetMeasCursor() const { return measCursor; }
 
+    //! Retrieves the computation mode for baseline.
+    /*! \return The current mode for computing the baseline.
+     */
+    stf::baseline_method GetBaselineMethod() const { return baselineMethod; }
+
     //! Retrieves the position of the left baseline cursor.
     /*! \return The index of the left baseline cursor within the current section.
      */
@@ -555,7 +572,7 @@ public:
 #endif
 
     //! Retrieves the mode of the latency start cursor.
-    /*! \return The current mode of the latency start cursor..
+    /*! \return The current mode of the latency start cursor.
      */
     stf::latency_mode GetLatencyStartMode() const { return latencyStartMode; }
 
@@ -709,6 +726,21 @@ public:
      */
     void SetMeasCursor(int value);
 
+    //! Sets whether the measurement cursor (crosshair) should be visible.
+    /*! \param value is true if the ruler will be visible, false otherwirse..
+     */
+    void SetMeasRuler(bool value) { ShowRuler = value; }
+    
+    //! Retrieves whether the measurement cursor (crosshair) is visible.
+    /*! \param true if the ruler is visible, false otherwirse..
+     */
+    bool GetMeasRuler() const { return ShowRuler;}
+
+    //! Sets the method to compute the baseline.
+    /*! \param value The new method to calculate the baseline.
+     */
+    void SetBaselineMethod(stf::baseline_method value) { baselineMethod = value; }
+
     //! Sets the position of the left baseline cursor.
     /*! \param value The index of the left baseline cursor within the current section.
      */
@@ -803,12 +835,12 @@ public:
     void SetRTFactor(int value);
 
     //! Sets the mode of the latency start cursor.
-    /*! \param value The new mode of the latency start cursor..
+    /*! \param value The new mode of the latency start cursor.
      */
     void SetLatencyStartMode(stf::latency_mode value) { latencyStartMode=value; }
 
     //! Sets the mode of the latency end cursor.
-    /*! \param value The new mode of the latency end cursor..
+    /*! \param value The new mode of the latency end cursor.
      */
     void SetLatencyEndMode(stf::latency_mode value) {
         latencyEndMode=value;
